==> cinc-foundation-3.2.8.tar.xz: cinc-foundation-3.2.8/CHANGELOG.md <==
# Changelog

<!-- latest_release 3.2.8 -->
## [3.2.8](https://github.com/chef/chef-foundation/tree/3.2.8) (2024-06-18)

#### Merged Pull Requests
- test openssl 3.0.9 on AIX [#131](https://github.com/chef/chef-foundation/pull/131) ([muthuja](https://github.com/muthuja))
<!-- latest_release -->

<!-- release_rollup since=3.2.7 -->
### Changes since 3.2.7 release

#### Merged Pull Requests
- test openssl 3.0.9 on AIX [#131](https://github.com/chef/chef-foundation/pull/131) ([muthuja](https://github.com/muthuja)) <!-- 3.2.8 -->
<!-- release_rollup -->

<!-- latest_stable_release -->
## [3.2.7](https://github.com/chef/chef-foundation/tree/3.2.7) (2024-06-14)

#### Merged Pull Requests
- Update config.yml [#7](https://github.com/chef/chef-foundation/pull/7) ([gcs-devel](https://github.com/gcs-devel))
- Set a custom install dir [#8](https://github.com/chef/chef-foundation/pull/8) ([gcs-devel](https://github.com/gcs-devel))
- Update package scripts [#9](https://github.com/chef/chef-foundation/pull/9) ([gcs-devel](https://github.com/gcs-devel))
- BS-28/chef foundation all platforms [#10](https://github.com/chef/chef-foundation/pull/10) ([gcs-devel](https://github.com/gcs-devel))
- Update platforms in Gemfile.lock [#11](https://github.com/chef/chef-foundation/pull/11) ([gcs-devel](https://github.com/gcs-devel))
- Use lockfile from chef/chef/omnibus [#12](https://github.com/chef/chef-foundation/pull/12) ([gcs-devel](https://github.com/gcs-devel))
- Add openssl customization files [#13](https://github.com/chef/chef-foundation/pull/13) ([gcs-devel](https://github.com/gcs-devel))
- Omit the ChefLogDllPath from foundation builds [#14](https://github.com/chef/chef-foundation/pull/14) ([gcs-devel](https://github.com/gcs-devel))
- Skip windows until the ami is fixed [#15](https://github.com/chef/chef-foundation/pull/15) ([gcs-devel](https://github.com/gcs-devel))
- Build only containerized platforms for now [#16](https://github.com/chef/chef-foundation/pull/16) ([gcs-devel](https://github.com/gcs-devel))
- Only build windows [#17](https://github.com/chef/chef-foundation/pull/17) ([gcs-devel](https://github.com/gcs-devel))
- Copied resources from chef/chef and modified WIX installer config [#18](https://github.com/chef/chef-foundation/pull/18) ([gcs-devel](https://github.com/gcs-devel))
- Skip windows again [#19](https://github.com/chef/chef-foundation/pull/19) ([gcs-devel](https://github.com/gcs-devel))
- Add the preinst package script [#20](https://github.com/chef/chef-foundation/pull/20) ([gcs-devel](https://github.com/gcs-devel))
- Use test version of omnibus-buildkite-plugin [#21](https://github.com/chef/chef-foundation/pull/21) ([gcs-devel](https://github.com/gcs-devel))
- Use test version of omnibus-buildkite-plugin [#22](https://github.com/chef/chef-foundation/pull/22) ([gcs-devel](https://github.com/gcs-devel))
- Set project location to chef-foundation [#23](https://github.com/chef/chef-foundation/pull/23) ([gcs-devel](https://github.com/gcs-devel))
- Fix windows [#24](https://github.com/chef/chef-foundation/pull/24) ([gcs-devel](https://github.com/gcs-devel))
- Renamed directory [#25](https://github.com/chef/chef-foundation/pull/25) ([gcs-devel](https://github.com/gcs-devel))
- Use version that creates directories [#27](https://github.com/chef/chef-foundation/pull/27) ([gcs-devel](https://github.com/gcs-devel))
- Gcs devel/build from internal src bs 109 [#28](https://github.com/chef/chef-foundation/pull/28) ([gcs-devel](https://github.com/gcs-devel))
- Disable internal sources until artifactory token is provided. [#29](https://github.com/chef/chef-foundation/pull/29) ([gcs-devel](https://github.com/gcs-devel))
- Use omnibus on development branch. [#30](https://github.com/chef/chef-foundation/pull/30) ([gcs-devel](https://github.com/gcs-devel))
- Remove wix folder create [#31](https://github.com/chef/chef-foundation/pull/31) ([gcs-devel](https://github.com/gcs-devel))
- Use artifactory rubygems proxy [#32](https://github.com/chef/chef-foundation/pull/32) ([gcs-devel](https://github.com/gcs-devel))
- Move back to using omnibus_overrides.rb [#33](https://github.com/chef/chef-foundation/pull/33) ([gcs-devel](https://github.com/gcs-devel))
- Revert to using rubygems.org as the default source. [#39](https://github.com/chef/chef-foundation/pull/39) ([gcs-devel](https://github.com/gcs-devel))
- Use external sources for now [#40](https://github.com/chef/chef-foundation/pull/40) ([gcs-devel](https://github.com/gcs-devel))
- Change package identifier. [#42](https://github.com/chef/chef-foundation/pull/42) ([gcs-devel](https://github.com/gcs-devel))
- re-enabling internal source flag for omnibus [#44](https://github.com/chef/chef-foundation/pull/44) ([justingruber](https://github.com/justingruber))
- bundle update to have correct commit with internal cachine fix in it [#50](https://github.com/chef/chef-foundation/pull/50) ([justingruber](https://github.com/justingruber))
- Update dependency to proxifier2  [#54](https://github.com/chef/chef-foundation/pull/54) ([vkarve-chef](https://github.com/vkarve-chef))
- Build with openssl 3.0.4 [#56](https://github.com/chef/chef-foundation/pull/56) ([poorndm](https://github.com/poorndm))
- Update Omnibus-s/w version to pick openssl config changes [#59](https://github.com/chef/chef-foundation/pull/59) ([poorndm](https://github.com/poorndm))
- CHEF-2776 Exclude AIX platform [#60](https://github.com/chef/chef-foundation/pull/60) ([poorndm](https://github.com/poorndm))
- Revert to using OpenSSL 1.0.xx  [#62](https://github.com/chef/chef-foundation/pull/62) ([vkarve-chef](https://github.com/vkarve-chef))
- updating code owners [#58](https://github.com/chef/chef-foundation/pull/58) ([sean-simmons-progress](https://github.com/sean-simmons-progress))
- Update openssl to 1.0.2ze [#63](https://github.com/chef/chef-foundation/pull/63) ([poorndm](https://github.com/poorndm))
- Add RockyLinux-8 builder &amp; Tester [#65](https://github.com/chef/chef-foundation/pull/65) ([poorndm](https://github.com/poorndm))
- Update openssl version to 1.0.2zf [#67](https://github.com/chef/chef-foundation/pull/67) ([muthuja](https://github.com/muthuja))
- Added rockylinux-9 to chef-foundation [#71](https://github.com/chef/chef-foundation/pull/71) ([muthuja](https://github.com/muthuja))
- updated gemfile lock omnibus version to 9.0.23 [#74](https://github.com/chef/chef-foundation/pull/74) ([muthuja](https://github.com/muthuja))
- Support Rocky-arm-8/9 [#81](https://github.com/chef/chef-foundation/pull/81) ([poorndm](https://github.com/poorndm))
- Updating openssl to 1.0.2zi [#84](https://github.com/chef/chef-foundation/pull/84) ([johnmccrae](https://github.com/johnmccrae))
- updating code owners [#88](https://github.com/chef/chef-foundation/pull/88) ([sean-simmons-progress](https://github.com/sean-simmons-progress))
- Jfm/chef18 openssl 1.0.2zi - part 2 [#85](https://github.com/chef/chef-foundation/pull/85) ([johnmccrae](https://github.com/johnmccrae))
- unpinned/removed libxslt and libxml2 [#87](https://github.com/chef/chef-foundation/pull/87) ([muthuja](https://github.com/muthuja))
- Downgrade bash to 5.1.8 on solaris [#100](https://github.com/chef/chef-foundation/pull/100) ([poorndm](https://github.com/poorndm))
- added amazon2023 builder and tester [#101](https://github.com/chef/chef-foundation/pull/101) ([muthuja](https://github.com/muthuja))
- openssl upgrade to 3.0.11 [#102](https://github.com/chef/chef-foundation/pull/102) ([muthuja](https://github.com/muthuja))
- 9.0.24 omnibus bump for Solaris pkgmogrify changes [#104](https://github.com/chef/chef-foundation/pull/104) ([tpowell-progress](https://github.com/tpowell-progress))
- Revert &quot;openssl upgrade to 3.0.11&quot; [#105](https://github.com/chef/chef-foundation/pull/105) ([tpowell-progress](https://github.com/tpowell-progress))
- To fix signature issue on Notarization [#106](https://github.com/chef/chef-foundation/pull/106) ([poorndm](https://github.com/poorndm))
- upgrade openssl version to 3.0.9 [#103](https://github.com/chef/chef-foundation/pull/103) ([muthuja](https://github.com/muthuja))
- Update Windows builder matching Infra-client  platforms [#108](https://github.com/chef/chef-foundation/pull/108) ([poorndm](https://github.com/poorndm))
- this is just test pr to check release pipeline build [#109](https://github.com/chef/chef-foundation/pull/109) ([muthuja](https://github.com/muthuja))
- remove mac 10.15 from release pipeline and add mac 11 as builder [#116](https://github.com/chef/chef-foundation/pull/116) ([muthuja](https://github.com/muthuja))
- gem openssl 3.0.0 install to be consistent with ruby 3.1.2 [#114](https://github.com/chef/chef-foundation/pull/114) ([muthuja](https://github.com/muthuja))
- Modify freebsd builder -freebsd-13 [#112](https://github.com/chef/chef-foundation/pull/112) ([poorndm](https://github.com/poorndm))
- Updating default versions to get past 2 CVE&#39;s [#125](https://github.com/chef/chef-foundation/pull/125) ([johnmccrae](https://github.com/johnmccrae))
- Build OpenSSL 3.0.9 and Ruby 3.1 (except AIX, Windows - 1.0.2zi and macOS 1.1.1m) [#121](https://github.com/chef/chef-foundation/pull/121) ([tpowell-progress](https://github.com/tpowell-progress))
- build freebsd-13 artifacts [#126](https://github.com/chef/chef-foundation/pull/126) ([muthuja](https://github.com/muthuja))
- Updating Omnibus Software [#127](https://github.com/chef/chef-foundation/pull/127) ([johnmccrae](https://github.com/johnmccrae))
- updated latest sha of omnibus-software [#128](https://github.com/chef/chef-foundation/pull/128) ([muthuja](https://github.com/muthuja))
- Updating chef-foundation to pull in patches [#129](https://github.com/chef/chef-foundation/pull/129) ([johnmccrae](https://github.com/johnmccrae))
<!-- latest_stable_release -->

==> cinc-foundation-3.2.35.tar.xz: cinc-foundation-3.2.35/CHANGELOG.md <==
# Changelog

<!-- latest_release -->
<!-- latest_release -->

<!-- release_rollup -->
<!-- release_rollup -->

<!-- latest_stable_release -->
## [3.2.35](https://github.com/chef/chef-foundation/tree/3.2.35) (2025-09-25)

#### Merged Pull Requests
- Modify internal_source env to fix Mac Intermittent build issue [#184](https://github.com/chef/chef-foundation/pull/184) ([poorndm](https://github.com/poorndm))
- Update for s3-private-access and windows cert update [#188](https://github.com/chef/chef-foundation/pull/188) ([poorndm](https://github.com/poorndm))
<!-- latest_stable_release -->

## [3.2.33](https://github.com/chef/chef-foundation/tree/3.2.33) (2025-08-11)

#### Merged Pull Requests
- omnibus-software bump for rbs -x removal [#183](https://github.com/chef/chef-foundation/pull/183) ([tpowell-progress](https://github.com/tpowell-progress))

## [3.2.32](https://github.com/chef/chef-foundation/tree/3.2.32) (2025-08-07)

#### Merged Pull Requests
- Update for bundled gem removal [#181](https://github.com/chef/chef-foundation/pull/181) ([tpowell-progress](https://github.com/tpowell-progress))

## [3.2.31](https://github.com/chef/chef-foundation/tree/3.2.31) (2025-08-05)

#### Merged Pull Requests
- updating omnibus-software version [#177](https://github.com/chef/chef-foundation/pull/177) ([johnmccrae](https://github.com/johnmccrae))
- Bump omnibus-sofware for typeprof removal [#179](https://github.com/chef/chef-foundation/pull/179) ([tpowell-progress](https://github.com/tpowell-progress))
- Upgarde libarchive - 3.8.1 [#178](https://github.com/chef/chef-foundation/pull/178) ([poorndm](https://github.com/poorndm))

## [3.2.28](https://github.com/chef/chef-foundation/tree/3.2.28) (2025-07-29)

#### Merged Pull Requests
- updating license scout version [#171](https://github.com/chef/chef-foundation/pull/171) ([johnmccrae](https://github.com/johnmccrae))
- Bump to OpenSSL 3.2.4, OpenSSL FIPS 3.1.2, openssl 3.3.0 [#174](https://github.com/chef/chef-foundation/pull/174) ([tpowell-progress](https://github.com/tpowell-progress))
- fix openssl 3.2.4 build [#175](https://github.com/chef/chef-foundation/pull/175) ([muthuja](https://github.com/muthuja))
- Ruby upgrade 3.1.7  and platform support windows2025 [#176](https://github.com/chef/chef-foundation/pull/176) ([poorndm](https://github.com/poorndm))

## [3.2.24](https://github.com/chef/chef-foundation/tree/3.2.24) (2025-06-26)

#### Merged Pull Requests
- Add Support for Ubuntu 24.04 [#165](https://github.com/chef/chef-foundation/pull/165) ([poorndm](https://github.com/poorndm))

## [3.2.23](https://github.com/chef/chef-foundation/tree/3.2.23) (2025-06-11)

#### Merged Pull Requests
- make pipelines public: verify [#153](https://github.com/chef/chef-foundation/pull/153) ([jaymzh](https://github.com/jaymzh))
- Add  libcrypt Dependency [#156](https://github.com/chef/chef-foundation/pull/156) ([poorndm](https://github.com/poorndm))
- Remove libxcrypt dependency [#158](https://github.com/chef/chef-foundation/pull/158) ([poorndm](https://github.com/poorndm))
- update nokogiri to 1.18.4 and libxslt to 1.1.43 [#161](https://github.com/chef/chef-foundation/pull/161) ([rishichawda](https://github.com/rishichawda))
- pin cgi to 0.3.7 to resolve CVE-2025-27219 and CVE-2025-27220 [#160](https://github.com/chef/chef-foundation/pull/160) ([rishichawda](https://github.com/rishichawda))
- update nokogiri to 1.18.8 and libxml2 to 2.13.8 [#162](https://github.com/chef/chef-foundation/pull/162) ([rishichawda](https://github.com/rishichawda))
- Test Version Bump [#164](https://github.com/chef/chef-foundation/pull/164) ([poorndm](https://github.com/poorndm))

## [3.2.15](https://github.com/chef/chef-foundation/tree/3.2.15) (2025-05-30)

## [3.2.14](https://github.com/chef/chef-foundation/tree/3.2.14) (2025-05-30)

## [3.2.13](https://github.com/chef/chef-foundation/tree/3.2.13) (2025-05-30)

## [3.2.16](https://github.com/chef/chef-foundation/tree/3.2.16) (2025-05-30)

#### Merged Pull Requests
- test openssl 3.0.9 on AIX [#131](https://github.com/chef/chef-foundation/pull/131) ([muthuja](https://github.com/muthuja))
- remove el-6 and update digi cert token for windows platforms [#135](https://github.com/chef/chef-foundation/pull/135) ([muthuja](https://github.com/muthuja))
- bump omnibus-software for 3.1.6 [#136](https://github.com/chef/chef-foundation/pull/136) ([tpowell-progress](https://github.com/tpowell-progress))
- Update windows devkit to 3.1.6 and omnibus-software for URL [#138](https://github.com/chef/chef-foundation/pull/138) ([tpowell-progress](https://github.com/tpowell-progress))
- Fix through -&gt; threw [#140](https://github.com/chef/chef-foundation/pull/140) ([tpowell-progress](https://github.com/tpowell-progress))
- Fix openssl- 3.2.0 gem issue and Update Mixlib-log gem [#148](https://github.com/chef/chef-foundation/pull/148) ([poorndm](https://github.com/poorndm))
- update nokogiri to overcome CVE and pin libxml2 and libxslt to overri… [#150](https://github.com/chef/chef-foundation/pull/150) ([muthuja](https://github.com/muthuja))
- remove mac 11 as its EOL and pick latest version of omnibus-software [#151](https://github.com/chef/chef-foundation/pull/151) ([muthuja](https://github.com/muthuja))
- Update pipeline to support macOS 13 and 14 ARM  [#152](https://github.com/chef/chef-foundation/pull/152) ([poorndm](https://github.com/poorndm))

## [3.2.7](https://github.com/chef/chef-foundation/tree/3.2.7) (2024-06-14)

#### Merged Pull Requests
- Update config.yml [#7](https://github.com/chef/chef-foundation/pull/7) ([gcs-devel](https://github.com/gcs-devel))
- Set a custom install dir [#8](https://github.com/chef/chef-foundation/pull/8) ([gcs-devel](https://github.com/gcs-devel))
- Update package scripts [#9](https://github.com/chef/chef-foundation/pull/9) ([gcs-devel](https://github.com/gcs-devel))
- BS-28/chef foundation all platforms [#10](https://github.com/chef/chef-foundation/pull/10) ([gcs-devel](https://github.com/gcs-devel))
- Update platforms in Gemfile.lock [#11](https://github.com/chef/chef-foundation/pull/11) ([gcs-devel](https://github.com/gcs-devel))
- Use lockfile from chef/chef/omnibus [#12](https://github.com/chef/chef-foundation/pull/12) ([gcs-devel](https://github.com/gcs-devel))
- Add openssl customization files [#13](https://github.com/chef/chef-foundation/pull/13) ([gcs-devel](https://github.com/gcs-devel))
- Omit the ChefLogDllPath from foundation builds [#14](https://github.com/chef/chef-foundation/pull/14) ([gcs-devel](https://github.com/gcs-devel))
- Skip windows until the ami is fixed [#15](https://github.com/chef/chef-foundation/pull/15) ([gcs-devel](https://github.com/gcs-devel))
- Build only containerized platforms for now [#16](https://github.com/chef/chef-foundation/pull/16) ([gcs-devel](https://github.com/gcs-devel))
- Only build windows [#17](https://github.com/chef/chef-foundation/pull/17) ([gcs-devel](https://github.com/gcs-devel))
- Copied resources from chef/chef and modified WIX installer config [#18](https://github.com/chef/chef-foundation/pull/18) ([gcs-devel](https://github.com/gcs-devel))
- Skip windows again [#19](https://github.com/chef/chef-foundation/pull/19) ([gcs-devel](https://github.com/gcs-devel))
- Add the preinst package script [#20](https://github.com/chef/chef-foundation/pull/20) ([gcs-devel](https://github.com/gcs-devel))
- Use test version of omnibus-buildkite-plugin [#21](https://github.com/chef/chef-foundation/pull/21) ([gcs-devel](https://github.com/gcs-devel))
- Use test version of omnibus-buildkite-plugin [#22](https://github.com/chef/chef-foundation/pull/22) ([gcs-devel](https://github.com/gcs-devel))
- Set project location to chef-foundation [#23](https://github.com/chef/chef-foundation/pull/23) ([gcs-devel](https://github.com/gcs-devel))
- Fix windows [#24](https://github.com/chef/chef-foundation/pull/24) ([gcs-devel](https://github.com/gcs-devel))
- Renamed directory [#25](https://github.com/chef/chef-foundation/pull/25) ([gcs-devel](https://github.com/gcs-devel))
- Use version that creates directories [#27](https://github.com/chef/chef-foundation/pull/27) ([gcs-devel](https://github.com/gcs-devel))
- Gcs devel/build from internal src bs 109 [#28](https://github.com/chef/chef-foundation/pull/28) ([gcs-devel](https://github.com/gcs-devel))
- Disable internal sources until artifactory token is provided. [#29](https://github.com/chef/chef-foundation/pull/29) ([gcs-devel](https://github.com/gcs-devel))
- Use omnibus on development branch. [#30](https://github.com/chef/chef-foundation/pull/30) ([gcs-devel](https://github.com/gcs-devel))
- Remove wix folder create [#31](https://github.com/chef/chef-foundation/pull/31) ([gcs-devel](https://github.com/gcs-devel))
- Use artifactory rubygems proxy [#32](https://github.com/chef/chef-foundation/pull/32) ([gcs-devel](https://github.com/gcs-devel))
- Move back to using omnibus_overrides.rb [#33](https://github.com/chef/chef-foundation/pull/33) ([gcs-devel](https://github.com/gcs-devel))
- Revert to using rubygems.org as the default source. [#39](https://github.com/chef/chef-foundation/pull/39) ([gcs-devel](https://github.com/gcs-devel))
- Use external sources for now [#40](https://github.com/chef/chef-foundation/pull/40) ([gcs-devel](https://github.com/gcs-devel))
- Change package identifier. [#42](https://github.com/chef/chef-foundation/pull/42) ([gcs-devel](https://github.com/gcs-devel))
- re-enabling internal source flag for omnibus [#44](https://github.com/chef/chef-foundation/pull/44) ([justingruber](https://github.com/justingruber))
- bundle update to have correct commit with internal cachine fix in it [#50](https://github.com/chef/chef-foundation/pull/50) ([justingruber](https://github.com/justingruber))
- Update dependency to proxifier2  [#54](https://github.com/chef/chef-foundation/pull/54) ([vkarve-chef](https://github.com/vkarve-chef))
- Build with openssl 3.0.4 [#56](https://github.com/chef/chef-foundation/pull/56) ([poorndm](https://github.com/poorndm))
- Update Omnibus-s/w version to pick openssl config changes [#59](https://github.com/chef/chef-foundation/pull/59) ([poorndm](https://github.com/poorndm))
- CHEF-2776 Exclude AIX platform [#60](https://github.com/chef/chef-foundation/pull/60) ([poorndm](https://github.com/poorndm))
- Revert to using OpenSSL 1.0.xx  [#62](https://github.com/chef/chef-foundation/pull/62) ([vkarve-chef](https://github.com/vkarve-chef))
- updating code owners [#58](https://github.com/chef/chef-foundation/pull/58) ([sean-simmons-progress](https://github.com/sean-simmons-progress))
- Update openssl to 1.0.2ze [#63](https://github.com/chef/chef-foundation/pull/63) ([poorndm](https://github.com/poorndm))
- Add RockyLinux-8 builder &amp; Tester [#65](https://github.com/chef/chef-foundation/pull/65) ([poorndm](https://github.com/poorndm))
- Update openssl version to 1.0.2zf [#67](https://github.com/chef/chef-foundation/pull/67) ([muthuja](https://github.com/muthuja))
- Added rockylinux-9 to chef-foundation [#71](https://github.com/chef/chef-foundation/pull/71) ([muthuja](https://github.com/muthuja))
- updated gemfile lock omnibus version to 9.0.23 [#74](https://github.com/chef/chef-foundation/pull/74) ([muthuja](https://github.com/muthuja))
- Support Rocky-arm-8/9 [#81](https://github.com/chef/chef-foundation/pull/81) ([poorndm](https://github.com/poorndm))
- Updating openssl to 1.0.2zi [#84](https://github.com/chef/chef-foundation/pull/84) ([johnmccrae](https://github.com/johnmccrae))
- updating code owners [#88](https://github.com/chef/chef-foundation/pull/88) ([sean-simmons-progress](https://github.com/sean-simmons-progress))
- Jfm/chef18 openssl 1.0.2zi - part 2 [#85](https://github.com/chef/chef-foundation/pull/85) ([johnmccrae](https://github.com/johnmccrae))
- unpinned/removed libxslt and libxml2 [#87](https://github.com/chef/chef-foundation/pull/87) ([muthuja](https://github.com/muthuja))
- Downgrade bash to 5.1.8 on solaris [#100](https://github.com/chef/chef-foundation/pull/100) ([poorndm](https://github.com/poorndm))
- added amazon2023 builder and tester [#101](https://github.com/chef/chef-foundation/pull/101) ([muthuja](https://github.com/muthuja))
- openssl upgrade to 3.0.11 [#102](https://github.com/chef/chef-foundation/pull/102) ([muthuja](https://github.com/muthuja))
- 9.0.24 omnibus bump for Solaris pkgmogrify changes [#104](https://github.com/chef/chef-foundation/pull/104) ([tpowell-progress](https://github.com/tpowell-progress))
- Revert &quot;openssl upgrade to 3.0.11&quot; [#105](https://github.com/chef/chef-foundation/pull/105) ([tpowell-progress](https://github.com/tpowell-progress))
- To fix signature issue on Notarization [#106](https://github.com/chef/chef-foundation/pull/106) ([poorndm](https://github.com/poorndm))
- upgrade openssl version to 3.0.9 [#103](https://github.com/chef/chef-foundation/pull/103) ([muthuja](https://github.com/muthuja))
- Update Windows builder matching Infra-client  platforms [#108](https://github.com/chef/chef-foundation/pull/108) ([poorndm](https://github.com/poorndm))
- this is just test pr to check release pipeline build [#109](https://github.com/chef/chef-foundation/pull/109) ([muthuja](https://github.com/muthuja))
- remove mac 10.15 from release pipeline and add mac 11 as builder [#116](https://github.com/chef/chef-foundation/pull/116) ([muthuja](https://github.com/muthuja))
- gem openssl 3.0.0 install to be consistent with ruby 3.1.2 [#114](https://github.com/chef/chef-foundation/pull/114) ([muthuja](https://github.com/muthuja))
- Modify freebsd builder -freebsd-13 [#112](https://github.com/chef/chef-foundation/pull/112) ([poorndm](https://github.com/poorndm))
- Updating default versions to get past 2 CVE&#39;s [#125](https://github.com/chef/chef-foundation/pull/125) ([johnmccrae](https://github.com/johnmccrae))
- Build OpenSSL 3.0.9 and Ruby 3.1 (except AIX, Windows - 1.0.2zi and macOS 1.1.1m) [#121](https://github.com/chef/chef-foundation/pull/121) ([tpowell-progress](https://github.com/tpowell-progress))
- build freebsd-13 artifacts [#126](https://github.com/chef/chef-foundation/pull/126) ([muthuja](https://github.com/muthuja))
- Updating Omnibus Software [#127](https://github.com/chef/chef-foundation/pull/127) ([johnmccrae](https://github.com/johnmccrae))
- updated latest sha of omnibus-software [#128](https://github.com/chef/chef-foundation/pull/128) ([muthuja](https://github.com/muthuja))
- Updating chef-foundation to pull in patches [#129](https://github.com/chef/chef-foundation/pull/129) ([johnmccrae](https://github.com/johnmccrae))
